(this["webpackJsonpstreamlit-html"]=this["webpackJsonpstreamlit-html"]||[]).push([[0],[,,,function(e,t,n){e.exports=n(4)},function(e,t,n){"use strict";n.r(t);var i=n(1),r=document.body.appendChild(document.createElement("div")),a=null;function o(){if(null!==a)return a;for(var e=window.parent.document.getElementsByTagName("iframe"),t=0;t<e.length;t++){var n,i=e[t];(i.contentDocument||(null===(n=i.contentWindow)||void 0===n?void 0:n.document))===document&&(a=i.parentElement)}return null===a&&console.error("Failed to identify the container of the HTML component"),a}var d=function(){var e;try{e=window.top||window.parent}catch(t){e=window.parent}return e}();window.stBridges=d.stBridges,void 0!==window.parent&&(window.parent.stBridges=d.stBridges),i.a.events.addEventListener(i.a.RENDER_EVENT,(function(e){var t=e.detail,n=t.args.html;if(!0===t.args.iframe)return r.innerHTML=n,void i.a.setFrameHeight();var a=o();if(null!==a){if("iframe"===a.lastElementChild.tagName.toLowerCase()){var d=window.parent.document.createElement("div");a.appendChild(d),a.firstElementChild.style.display="none"}a.lastElementChild.innerHTML=n}})),i.a.setComponentReady(),i.a.setFrameHeight()}],[[3,1,2]]]);
//# sourceMappingURL=main.44cfd5e2.chunk.js.map