self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "83498d3a337a0cc5e1918e1ef635b7e2",
    "url": "./index.html"
  },
  {
    "revision": "79f3664c334f065fbae9",
    "url": "./static/js/2.d57250d1.chunk.js"
  },
  {
    "revision": "b5321db7731dbb9a09b1fc4c60b61213",
    "url": "./static/js/2.d57250d1.chunk.js.LICENSE.txt"
  },
  {
    "revision": "f5707067d3a368089b77",
    "url": "./static/js/main.4c504d7b.chunk.js"
  },
  {
    "revision": "5e8ec43ca3bba2a86cdb",
    "url": "./static/js/runtime-main.f43d5da3.js"
  }
]);