(this["webpackJsonpstreamlit-bridge"]=this["webpackJsonpstreamlit-bridge"]||[]).push([[0],{5:function(e,t,n){e.exports=n(6)},6:function(e,t,n){"use strict";n.r(t);var i=n(0),s=n(1),a=n(3),r=function(){function e(t,n){Object(i.a)(this,e),this.name=void 0,this.key=void 0,this.name=t,this.key=n}return Object(s.a)(e,[{key:"send",value:function(e){a.a.setComponentValue(e)}}]),e}();var o=function(){var e;try{e=window.top||window.parent}catch(t){e=window.parent}return e}();if(void 0===o.stBridges){var d={bridges:{},send:function(e,t){d.bridges[e].send(t)}};o.stBridges=d}a.a.events.addEventListener(a.a.RENDER_EVENT,(function(e){var t=e.detail,n=o.stBridges,i=t.args.name,s=t.args.key;n.bridges[i]=new r(i,s)})),a.a.setComponentReady()}},[[5,1,2]]]);
//# sourceMappingURL=main.4c504d7b.chunk.js.map