self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "6e8a1239529ffb063da2a4a037d188c8",
    "url": "./index.html"
  },
  {
    "revision": "690a75933381ef4f9fde",
    "url": "./static/js/2.d68ca85c.chunk.js"
  },
  {
    "revision": "b5321db7731dbb9a09b1fc4c60b61213",
    "url": "./static/js/2.d68ca85c.chunk.js.LICENSE.txt"
  },
  {
    "revision": "140e34d26e2eb65712ec",
    "url": "./static/js/main.44cfd5e2.chunk.js"
  },
  {
    "revision": "2be61b5108aa2269d46b",
    "url": "./static/js/runtime-main.d8806d63.js"
  }
]);